@@ -15,18 +15,18 @@ alfa <- function(x, a, h = TRUE) {
   x <- as.matrix(x)  ## makes sure x is a matrix
   D <- ncol(x) ## number of components
   if ( D == 1 )   x <- t(x)
-  x <-  x / rowSums(x)  ## makes sure x is compositional data
+  x <-x / as.vector( Rfast::rowsums(x) )  ## makes sure x is compositional data
 
   if (a != 0) {
     z <- x^a
-    ta <- rowSums(z)
+    ta <- as.vector( Rfast::rowsums(z) )
     z <- z / ta
     z <- (D/a) * z - 1/a
     sa <- sum( log(ta) )
 
   } else {  ## if a=0 the ilr is calculated
     xa <- log(x)
-    z <- xa - rowMeans( xa )  ## this is the clr
+    z <- xa - as.vector( Rfast::rowmeans( xa ) )  ## this is the clr
     sa <- nrow(x) * log(D)
   }
 
