@@ -16,7 +16,7 @@ el.test1 <- function(x, mu, R = 1, ncores = 1, graph = FALSE) {
     tb <- numeric(R)
     n <- nrow(x)
     d <- ncol(x)
-    m <- colMeans(x)
+    m <- as.vector( Rfast::colmeans(x) )
     y <- x - rep( m - mu, rep(n, d) ) ## brings the data under the null hypothesis
 
     if (ncores == 1) {
