@@ -11,17 +11,17 @@ frechet <- function(x, a) {
   ## x contains the compositional data
   ## a is the power parameter, usually between -1 and 1
   x <- as.matrix(x)  ## makes sure x is a matrix
-  x <- x / rowSums(x)  ## makes sure x is compositional data
+  x <- x / as.vector( Rfast::rowsums(x) )  ## makes sure x is compositional data
 
   if (a == 0) {
      xa <- log(x)
-     y <- xa - rowMeans(xa)
+     y <- xa - as.vector( Rfast::rowmeans(xa) )
      m1 <- exp( as.vector( Rfast::colmeans(y) ) )
      m <- m1 / sum( m1 )  ## closed geometric mean
 
   }  else {
      xa <- x^a
-     z <- xa / rowSums(xa)
+     z <- xa / as.vector( Rfast::rowmeans(xa) )
      m1 <- as.vector( Rfast::colmeans(z) ) ^ ( 1 / a )
      m <- m1 / sum(m1)  ## frechet mean in general
   }
