@@ -21,11 +21,11 @@ mkde <- function(x, h, thumb = "none") {
   d <- ncol(x)  ## sample and dimensionality of x
 
   if ( thumb == "silverman" ) {
-    s <- as.vector( Rfast::colVars(x, std = TRUE) )
+    s <- Rfast::colVars(x, std = TRUE) 
     h <- ( 4/(d + 2) )^( 1/(d + 4) ) * s * n^( -1/(d + 4) )
 
   } else  if ( thumb == "scott" ) {
-    s <- as.vector( Rfast::colVars(x, std = TRUE) )
+    s <- Rfast::colVars(x, std = TRUE) 
     h <- s * n^( -1/(d + 4) )
 
   } else if ( thumb == "estim" ) {
@@ -40,7 +40,7 @@ mkde <- function(x, h, thumb = "none") {
   con <- prod( diag( h ) )
   y <- x %*% h
   a1 <- fields::rdist(y, compact = FALSE)
-  f <- as.vector( 1/(2 * pi)^(d/2) * con * rowMeans( exp(-0.5 * a1^2 ) ) )
+  f <- 1/(2 * pi)^(d/2) * con * as.vector( Rfast::rowmeans( exp(-0.5 * a1^2 ) ) )
   f
 
 }
