@@ -18,7 +18,7 @@ mkde.tune <- function( x, low = 0.1, up = 3, s = cov(x) ) {
   ## low and up are the limits within which the
   ## search is conducted
 
-    
+
   x <- as.matrix(x)
   n <- nrow(x)
   d <- ncol(x)  ## sample and dimensionality of x
@@ -35,13 +35,12 @@ mkde.tune <- function( x, low = 0.1, up = 3, s = cov(x) ) {
 
   tune <- function(h) {
     a <- a2a^( 1 / h^2 )
-    f <- ds / (2 * pi)^(d/2) * (1/h^d) * ( rowSums( a ) - 1 ) / (n - 1)
-    mean( log(f) )
-   }
+    f <- log(ds) -d/2 * log(2 * pi) - d * log(h) - log(n - 1) + log( rowSums( a ) - 1 )
+    mean( f )
+  }
   low <- low    ;   up <- up
 
   bar <- optimize(tune, c(low, up), maximum = TRUE)
   list( hopt = bar$maximum, maximum = bar$objective )
 
 }
-
