@@ -18,7 +18,7 @@ ols.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
 
   runtime <- proc.time()
   y <- as.matrix(y)
-  y <- y/rowSums(y)  ## makes sure y is compositional data
+  y <- y / as.vector( Rfast::rowsums(y) ) ## makes sure y is compositional data
   x <- as.matrix( cbind(1, x) )
   d <- ncol(y) - 1  ## dimensionality of the simplex
   n <- nrow(y)  ## sample size
@@ -89,12 +89,12 @@ ols.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
 
   if ( is.null(xnew) ) {
     mu <- cbind( 1, exp(x %*% beta) )
-    est <- mu / rowSums(mu)
+    est <- mu / as.vector( Rfast::rowsums(mu) )
   } else {
     xnew <- cbind(1, xnew)
     xnew <- as.matrix(xnew)
     mu <- cbind(1, exp(x %*% beta))
-    est <- mu / rowSums(mu)
+    est <- mu / as.vector( Rfast::rowsums(mu) )
   }
 
   if ( is.null(colnames(x)) ) {
